@@ -5,31 +5,25 @@ use warnings;
 
 use lib '../..';
 
-use base qw(App::Followme::HandleSite);
+use base qw(App::Followme::Module);
 
 use File::Spec::Functions qw(abs2rel catfile no_upwards rel2abs splitdir);
 
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
 
 sub parameters {
-    my ($pkg) = @_;
+    my ($self) = @_;
     
-    my %parameters = (
-                      news_file => '../blog.html',
-                      news_index_file => 'index.html',
-                      news_index_length => 5,
-                      body_tag => 'content',
-                      news_template => 'news.htm',
-                      news_index_template => 'news_index.htm',
-                     );
-
-    my %base_params = $pkg->SUPER::parameters();
-    %parameters = (%base_params, %parameters);
-
-    return %parameters;
+    return (
+            news_file => '../blog.html',
+            news_index_file => 'index.html',
+            news_index_length => 5,
+            news_template => 'news.htm',
+            news_index_template => 'news_index.htm',
+           );
 }
 
 #----------------------------------------------------------------------
@@ -55,12 +49,13 @@ sub run {
 sub create_an_index {
     my ($self, $directory, $directories, $filenames) = @_;
     
-    my $index_name = $self->full_file_name($directory, $self->{news_index_file});
-    my $template_name = $self->get_template_name($self->{news_index_template});
-
     # Don't re-create index if directory and template haven't changed
     
-    return if $self->is_newer($index_name, $template_name, $directory);
+    my $index_name = $self->full_file_name($directory, $self->{news_index_file});
+
+    return if $self->index_is_newer($index_name,
+                                    $self->{news_index_template},
+                                    $directory);
     
     my $data = $self->set_fields($directory, $index_name);    
     $data->{loop} = $self->index_data($directory, $directories, $filenames);
@@ -128,34 +123,18 @@ sub index_data {
     
     my @index_data;
     foreach my $filename (@$directories) {
+        next unless $self->search_directory($filename);
         push(@index_data, $self->set_fields($directory, $filename));
     }
 
     foreach my $filename (@$filenames) {
+        next unless $self->match_file($filename);
         push(@index_data, $self->set_fields($directory, $filename));
     }
 
     return \@index_data;
 }
 
-#----------------------------------------------------------------------
-# Get the body field from the file
-
-sub internal_fields {
-    my ($self, $data, $filename) = @_;   
-    
-    my $page = $self->read_page($filename);
-    
-    if ($page) {
-        my $sections = $self->parse_sections($page);
-        $data->{body} = $sections->{$self->{body_tag}};
-        $data->{summary} = $self->build_summary($data);
-        $data = $self->build_title_from_header($data);
-    }
-    
-    return $data;
-}
-
 #----------------------------------------------------------------------
 # Get the more recently changed files
 
@@ -171,6 +150,8 @@ sub more_recent_files {
     # Add file to list of recent files if modified more recently than others
 
     foreach my $filename (@$filenames) {
+        next unless $self->match_file($filename);
+
         my @stats = stat($filename);        
         if (@$augmented_files < $limit || $stats[9] > $augmented_files->[0][0]) {
     
@@ -257,14 +238,18 @@ the text of the most recently modified files together with links to the files,
 It can be used to create a basic weblog. The index is built using a template.
 The template has Loop comments that look like
 
-    <!-- loop -->
-    <!-- endloop -->
+    <!-- for @loop -->
+    <!-- endfor -->
 
 and indicate the section of the template that is repeated for each file
 contained in the index. The following variables may be used in the template:
 
 =over 4
 
+=item absolute_url
+
+The absolute_url of the web page.
+
 =item body
 
 All the text inside the content tags in an page.
@@ -277,7 +262,7 @@ capitalizing the first character of each word.
 
 =item url
 
-The relative url of an html page. 
+The relative url of a web page. 
 
 =item time fields
 
